@@ -1,15 +1,16 @@
 """
 Type annotations for sts service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/)
 
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_sts import STSClient
+    from boto3.session import Session
+    from mypy_boto3_sts.client import STSClient
 
-    client: STSClient = boto3.client("sts")
+    session = Session()
+    client: STSClient = session.client("sts")
     ```
 """
 from typing import Any, Dict, Mapping, Sequence, Type
@@ -54,8 +55,8 @@ class Exceptions:
 
 class STSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/)
     """
 
     meta: ClientMeta
@@ -64,6 +65,9 @@ class STSClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         STSClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#exceptions)
         """
 
     def assume_role(
@@ -85,8 +89,8 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials that you can use to access
         Amazon Web Services resources that you might not normally have access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.assume_role)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#assume_role)
         """
 
     def assume_role_with_saml(
@@ -103,8 +107,8 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials for users who have been
         authenticated via a SAML authentication response.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.assume_role_with_saml)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_saml)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#assume_role_with_saml)
         """
 
     def assume_role_with_web_identity(
@@ -122,16 +126,16 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials for users who have been
         authenticated in a mobile or web application with a web identity provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_web_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#assume_role_with_web_identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#can_paginate)
         """
 
     def decode_authorization_message(
@@ -141,8 +145,8 @@ class STSClient(BaseClient):
         Decodes additional information about the authorization status of a request from
         an encoded message returned in response to an Amazon Web Services request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.decode_authorization_message)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode_authorization_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#decode_authorization_message)
         """
 
     def generate_presigned_url(
@@ -155,16 +159,16 @@ class STSClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#generate_presigned_url)
         """
 
     def get_access_key_info(self, *, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
         Returns the account identifier for the specified access key ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.get_access_key_info)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_access_key_info)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#get_access_key_info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
@@ -172,8 +176,8 @@ class STSClient(BaseClient):
         Returns details about the IAM user or role whose credentials are used to call
         the operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.get_caller_identity)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_caller_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#get_caller_identity)
         """
 
     def get_federation_token(
@@ -189,8 +193,8 @@ class STSClient(BaseClient):
         Returns a set of temporary security credentials (consisting of an access key ID,
         a secret access key, and a security token) for a federated user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.get_federation_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_federation_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#get_federation_token)
         """
 
     def get_session_token(
@@ -200,6 +204,6 @@ class STSClient(BaseClient):
         Returns a set of temporary credentials for an Amazon Web Services account or IAM
         user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/sts.html#STS.Client.get_session_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_session_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#get_session_token)
         """
