@@ -1,14 +1,14 @@
 """
 Type annotations for sts service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/literals/)
 
 Usage::
 
     ```python
-    from mypy_boto3_sts.literals import ServiceName
+    from mypy_boto3_sts.literals import STSServiceName
 
-    data: ServiceName = "accessanalyzer"
+    data: STSServiceName = "sts"
     ```
 """
 import sys
@@ -19,9 +19,10 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ServiceName",)
+__all__ = ("STSServiceName", "ServiceName", "ResourceServiceName", "RegionName")
 
 
+STSServiceName = Literal["sts"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -53,6 +54,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -139,6 +141,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -175,6 +178,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -323,3 +327,39 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
